@@ -9,5 +9,5 @@ class GenericServiceSerializer(ModelSerializer):
     def create(self, validated_data):
         try:
             return super().create(validated_data)
-        except exceptions.ClientError as e:
+        except exceptions.ServiceClientError as e:
             raise ValidationError({api_settings.NON_FIELD_ERRORS_KEY: [e]})
